@@ -6,15 +6,13 @@
 #define KINIT_H
 
 #include <stddef.h>
+#include <stdio.h>
+#include <sys/types.h>
 
-void dump_args(int argc, char *argv[]);
 int do_mounts(int argc, char *argv[]);
 int mount_nfs_root(int argc, char *argv[], int flags);
-char *get_arg(int argc, char *argv[], const char *name);
-int get_flag(int argc, char *argv[], const char *name);
 int ramdisk_load(int argc, char *argv[], dev_t root_dev);
 void md_run(int argc, char *argv[]);
-int do_resume(int argc, char *argv[]);
 const char *bdevname(dev_t dev);
 
 extern int mnt_procfs;
@@ -24,8 +22,11 @@ extern int init_argc;
 extern char **init_argv;
 extern const char *progname;
 
-int open_cloexec(const char *path, int flags, mode_t mode);
+char *get_arg(int argc, char *argv[], const char *name);
+int get_flag(int argc, char *argv[], const char *name);
+
 int getintfile(const char *path, long *val);
+
 ssize_t readfile(const char *path, char **pptr);
 ssize_t freadfile(FILE *f, char **pptr);
 
@@ -56,4 +57,14 @@ ssize_t freadfile(FILE *f, char **pptr);
 #define DEBUG(x) do { } while (0)
 #endif
 
+#ifdef INI_DEBUG
+void dump_args(int argc, char *argv[]);
+#else
+static inline void dump_args(int argc, char *argv[])
+{
+	(void)argc;
+	(void)argv;
+}
+#endif
+
 #endif				/* KINIT_H */
